package com.ruoyi.frequency.givewallerecord.service;

import java.math.BigDecimal;
import java.util.List;

import com.ruoyi.controller.req.WalletPageReq;
import com.ruoyi.controller.resp.WalletPageResp;
import com.ruoyi.enums.WalletDetailEnums;
import com.ruoyi.frequency.givewallerecord.entity.GiveWalletRecord;
import com.baomidou.mybatisplus.extension.service.IService;
import com.ruoyi.response.ResponseData;
import com.ruoyi.vo.UserVo;

/**
 * 抵用金钱包记录Service接口
 * 
 * @author liwenlong
 * @date 2024-05-18
 */
public interface GiveWalletRecordService extends IService<GiveWalletRecord>
{
    /**
     * 查询抵用金钱包记录
     * 
     * @param id 抵用金钱包记录主键
     * @return 抵用金钱包记录
     */
    public GiveWalletRecord selectGiveWalletRecordById(Long id);

    /**
     * 查询抵用金钱包记录列表
     * 
     * @param giveWalletRecord 抵用金钱包记录
     * @return 抵用金钱包记录集合
     */
    public List<GiveWalletRecord> selectGiveWalletRecordList(GiveWalletRecord giveWalletRecord);

    /**
     * 新增抵用金钱包记录
     * 
     * @param giveWalletRecord 抵用金钱包记录
     * @return 结果
     */
    public int insertGiveWalletRecord(GiveWalletRecord giveWalletRecord);

    /**
     * 修改抵用金钱包记录
     * 
     * @param giveWalletRecord 抵用金钱包记录
     * @return 结果
     */
    public int updateGiveWalletRecord(GiveWalletRecord giveWalletRecord);

    /**
     * 批量删除抵用金钱包记录
     * 
     * @param ids 需要删除的抵用金钱包记录主键集合
     * @return 结果
     */
    public int deleteGiveWalletRecordByIds(Long[] ids,Integer delFlag);

    void updateGiveBalance(UserVo userVo, WalletDetailEnums walletDetailEnums, Long objectId, BigDecimal updatePrice, Integer status);

    ResponseData<WalletPageResp> giveWalletPage(WalletPageReq req, UserVo userVo);
}
